.. redirect-from:: /users/prev_whats_new/github_stats_3.9.1

.. _github-stats-3-9-1:

GitHub statistics for 3.9.1 (Jul 04, 2024)
==========================================

GitHub statistics for 2024/05/15 (tag: v3.9.0) - 2024/07/04

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 30 issues and merged 111 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/91?closed=1>`__

The following 29 authors contributed 184 commits.

* Antony Lee
* Brigitta Sipőcz
* Christian Mattsson
* dale
* dependabot[bot]
* Elliott Sales de Andrade
* Eytan Adler
* Greg Lucas
* haaris
* hannah
* Ian Thomas
* Illviljan
* K900
* Kyle Sunden
* Lumberbot (aka Jack)
* malhar2460
* Matthew Feickert
* Melissa Weber Mendonça
* MischaMegens2
* Oscar Gustafsson
* Ruth Comer
* Scott Shambaugh
* simond07
* SjoerdB93
* Takumasa N
* Takumasa N.
* Takumasa Nakamura
* Thomas A Caswell
* Tim Hoffmann

GitHub issues and pull requests:

Pull Requests (111):

* :ghpull:`28507`: Backport PR #28430 on branch v3.9.x (Fix pickling of AxesWidgets.)
* :ghpull:`28506`: Backport PR #28451 on branch v3.9.x (Fix GTK cairo backends)
* :ghpull:`28430`: Fix pickling of AxesWidgets.
* :ghpull:`25861`: Fix Hidpi scaling for GTK4Cairo
* :ghpull:`28451`: Fix GTK cairo backends
* :ghpull:`28499`: Backport PR #28498 on branch v3.9.x (Don't fail if we can't query system fonts on macOS)
* :ghpull:`28498`: Don't fail if we can't query system fonts on macOS
* :ghpull:`28491`: Backport PR #28487 on branch v3.9.x (Fix autoscaling with axhspan)
* :ghpull:`28490`: Backport PR #28486 on branch v3.9.x (Fix CompositeGenericTransform.contains_branch_seperately)
* :ghpull:`28487`: Fix autoscaling with axhspan
* :ghpull:`28486`: Fix CompositeGenericTransform.contains_branch_seperately
* :ghpull:`28483`: Backport PR #28393 on branch v3.9.x (Make sticky edges only apply if the sticky edge is the most extreme limit point)
* :ghpull:`28482`: Backport PR #28473 on branch v3.9.x (Do not lowercase module:// backends)
* :ghpull:`28393`: Make sticky edges only apply if the sticky edge is the most extreme limit point
* :ghpull:`28473`: Do not lowercase module:// backends
* :ghpull:`28480`: Backport PR #28474 on branch v3.9.x (Fix typing and docs for containers)
* :ghpull:`28479`: Backport PR #28397 (FIX: stale root Figure when adding/updating subfigures)
* :ghpull:`28474`: Fix typing and docs for containers
* :ghpull:`28472`: Backport PR #28289 on branch v3.9.x (Promote mpltype Sphinx role to a public extension)
* :ghpull:`28471`: Backport PR #28342 on branch v3.9.x (DOC: Document the parameter *position* of apply_aspect() as internal)
* :ghpull:`28470`: Backport PR #28398 on branch v3.9.x (Add GIL Release to flush_events in macosx backend)
* :ghpull:`28469`: Backport PR #28355 on branch v3.9.x (MNT: Re-add matplotlib.cm.get_cmap)
* :ghpull:`28397`: FIX: stale root Figure when adding/updating subfigures
* :ghpull:`28289`: Promote mpltype Sphinx role to a public extension
* :ghpull:`28342`: DOC: Document the parameter *position* of apply_aspect() as internal
* :ghpull:`28398`: Add GIL Release to flush_events in macosx backend
* :ghpull:`28355`: MNT: Re-add matplotlib.cm.get_cmap
* :ghpull:`28468`: Backport PR #28465 on branch v3.9.x (Fix pickling of SubFigures)
* :ghpull:`28465`: Fix pickling of SubFigures
* :ghpull:`28462`: Backport PR #28440 on branch v3.9.x (DOC: Add note about simplification of to_polygons)
* :ghpull:`28460`: Backport PR #28459 on branch v3.9.x (DOC: Document kwargs scope for tick setter functions)
* :ghpull:`28461`: Backport PR #28458 on branch v3.9.x (Correct numpy dtype comparisons in image_resample)
* :ghpull:`28440`: DOC: Add note about simplification of to_polygons
* :ghpull:`28458`: Correct numpy dtype comparisons in image_resample
* :ghpull:`28459`: DOC: Document kwargs scope for tick setter functions
* :ghpull:`28450`: Backport of 28371 and 28411
* :ghpull:`28446`: Backport PR #28403 on branch v3.9.x (FIX: Autoscale support in add_collection3d for Line3DCollection and Poly3DCollection
* :ghpull:`28445`: Backport PR #28403 on branch v3.9.x (FIX: Autoscale support in add_collection3d for Line3DCollection and Poly3DCollection)
* :ghpull:`28438`: Backport PR #28436 on branch v3.9.x (Fix ``is_color_like`` for 2-tuple of strings and fix ``to_rgba`` for ``(nth_color, alpha)``)
* :ghpull:`28403`: FIX: Autoscale support in add_collection3d for Line3DCollection and Poly3DCollection
* :ghpull:`28443`: Backport PR #28441 on branch v3.9.x (MNT: Update basic units example to work with numpy 2.0)
* :ghpull:`28441`: MNT: Update basic units example to work with numpy 2.0
* :ghpull:`28436`: Fix ``is_color_like`` for 2-tuple of strings and fix ``to_rgba`` for ``(nth_color, alpha)``
* :ghpull:`28426`: Backport PR #28425 on branch v3.9.x (Fix Circle yaml line length)
* :ghpull:`28427`: Fix circleci yaml
* :ghpull:`28425`: Fix Circle yaml line length
* :ghpull:`28422`: Backport PR #28401 on branch v3.9.x (FIX: Fix text wrapping)
* :ghpull:`28424`: Backport PR #28423 on branch v3.9.x (Update return type for Axes.axhspan and Axes.axvspan)
* :ghpull:`28423`: Update return type for Axes.axhspan and Axes.axvspan
* :ghpull:`28401`: FIX: Fix text wrapping
* :ghpull:`28419`: Backport PR #28414 on branch v3.9.x (Clean up obsolete widget code)
* :ghpull:`28411`: Bump the actions group with 3 updates
* :ghpull:`28414`: Clean up obsolete widget code
* :ghpull:`28415`: Backport PR #28413 on branch v3.9.x (CI: update action that got moved org)
* :ghpull:`28413`: CI: update action that got moved org
* :ghpull:`28392`: Backport PR #28388 on branch v3.9.x (Allow duplicate (name, value) entry points for backends)
* :ghpull:`28362`: Backport PR #28337 on branch v3.9.x (Bump the actions group across 1 directory with 3 updates)
* :ghpull:`28388`: Allow duplicate (name, value) entry points for backends
* :ghpull:`28389`: Backport PR #28380 on branch v3.9.x (Remove outdated docstring section in RendererBase.draw_text.)
* :ghpull:`28380`: Remove outdated docstring section in RendererBase.draw_text.
* :ghpull:`28385`: Backport PR #28377 on branch v3.9.x (DOC: Clarify scope of wrap.)
* :ghpull:`28377`: DOC: Clarify scope of wrap.
* :ghpull:`28368`: Backport PR #28359 on branch v3.9.x (Document that axes unsharing is impossible.)
* :ghpull:`28359`: Document that axes unsharing is impossible.
* :ghpull:`28337`: Bump the actions group across 1 directory with 3 updates
* :ghpull:`28351`: Backport PR #28307 on branch v3.9.x (DOC: New color line by value example)
* :ghpull:`28307`: DOC: New color line by value example
* :ghpull:`28339`: Backport PR #28336 on branch v3.9.x (DOC: Add version warning banner for docs versions different from stable)
* :ghpull:`28336`: DOC: Add version warning banner for docs versions different from stable
* :ghpull:`28334`: Backport PR #28332 on branch v3.9.x (Call IPython.enable_gui when install repl displayhook)
* :ghpull:`28332`: Call IPython.enable_gui when install repl displayhook
* :ghpull:`28331`: Backport PR #28329 on branch v3.9.x (DOC: Add example for 3D intersecting planes)
* :ghpull:`28329`: DOC: Add example for 3D intersecting planes
* :ghpull:`28327`: Backport PR #28292 on branch v3.9.x (Resolve MaxNLocator IndexError when no large steps)
* :ghpull:`28292`: Resolve MaxNLocator IndexError when no large steps
* :ghpull:`28326`: Backport PR #28041 on branch v3.9.x ([BUG]: Shift box_aspect according to vertical_axis)
* :ghpull:`28041`: [BUG]: Shift box_aspect according to vertical_axis
* :ghpull:`28320`: Backport PR #27001 on branch v3.9.x ([TYP] Add overload of ``pyplot.subplots``)
* :ghpull:`27001`: [TYP] Add overload of ``pyplot.subplots``
* :ghpull:`28318`: Backport PR #28273 on branch v3.9.x (CI: Add GitHub artifact attestations to package distribution)
* :ghpull:`28273`: CI: Add GitHub artifact attestations to package distribution
* :ghpull:`28305`: Backport PR #28303 on branch v3.9.x (Removed drawedges repeated definition from function doc string)
* :ghpull:`28303`: Removed drawedges repeated definition from function doc string
* :ghpull:`28299`: Backport PR #28297 on branch v3.9.x (Solved #28296 Added missing comma)
* :ghpull:`28297`: Solved #28296 Added missing comma
* :ghpull:`28294`: Backport PR #28261 on branch v3.9.x (Correct roll angle units, issue #28256)
* :ghpull:`28261`: Correct roll angle units, issue #28256
* :ghpull:`28283`: Backport PR #28280 on branch v3.9.x (DOC: Add an example for 2D images in 3D plots)
* :ghpull:`28280`: DOC: Add an example for 2D images in 3D plots
* :ghpull:`28278`: Backport PR #28272 on branch v3.9.x (BLD: Move macos builders from 11 to 12)
* :ghpull:`28277`: Backport PR #28274 on branch v3.9.x (ci: Remove deprecated codeql option)
* :ghpull:`28272`: BLD: Move macos builders from 11 to 12
* :ghpull:`28274`: ci: Remove deprecated codeql option
* :ghpull:`28270`: Backport PR #28269 on branch v3.9.x (Handle GetForegroundWindow() returning NULL.)
* :ghpull:`28269`: Handle GetForegroundWindow() returning NULL.
* :ghpull:`28266`: Backport PR #28257 on branch v3.9.x (Clean up some Meson-related leftovers)
* :ghpull:`28257`: Clean up some Meson-related leftovers
* :ghpull:`28255`: Backport PR #28254 on branch v3.9.x ([DOC] plot type heading consistency)
* :ghpull:`28254`: [DOC] plot type heading consistency
* :ghpull:`28253`: Backport PR #28252 on branch v3.9.x (DOC: Flip the imshow plot types example to match the other examples)
* :ghpull:`28252`: DOC: Flip the imshow plot types example to match the other examples
* :ghpull:`28247`: Backport PR #28230 on branch v3.9.x (Add extra imports to improve typing)
* :ghpull:`28230`: Add extra imports to improve typing
* :ghpull:`28246`: Backport PR #28243 on branch v3.9.x (DOC: Add more 3D plot types)
* :ghpull:`28243`: DOC: Add more 3D plot types
* :ghpull:`28241`: Backport PR #28219 on branch v3.9.x (Bump the actions group with 2 updates)
* :ghpull:`28219`: Bump the actions group with 2 updates
* :ghpull:`28237`: Backport PR #28233 on branch v3.9.x (CI: Fix font install on macOS/Homebrew)
* :ghpull:`28236`: Backport PR #28231 on branch v3.9.x (DOC: we do not need the blit call in on_draw)
* :ghpull:`28233`: CI: Fix font install on macOS/Homebrew
* :ghpull:`28231`: DOC: we do not need the blit call in on_draw

Issues (30):

* :ghissue:`22482`: [ENH]: pickle (or save) matplotlib figure with insteractive slider
* :ghissue:`25847`: [Bug]: Graph gets cut off with scaled resolution using gtk4cairo backend
* :ghissue:`28341`: [Bug]: Incorrect X-axis scaling with date values
* :ghissue:`28383`: [Bug]: axvspan no longer participating in limit calculations
* :ghissue:`28223`: [Bug]: Inconsistent Visualization of Intervals in ax.barh for Different Duration Widths
* :ghissue:`28432`: [Bug]: Backend name specified as module gets lowercased since 3.9
* :ghissue:`28467`: [Bug]: Incorrect type stub for ``ErrorbarContainer``'s ``lines`` attribute.
* :ghissue:`28384`: [Bug]: subfigure artists not drawn interactively
* :ghissue:`28234`: [Bug]: mpltype custom role breaks sphinx build for third-party projects that have intersphinx links to matplotlib
* :ghissue:`28464`: [Bug]: figure with subfigures cannot be pickled
* :ghissue:`28448`: [Bug]: Making an RGB image from pickled data throws error
* :ghissue:`23317`: [Bug]: ``add_collection3d`` does not update view limits
* :ghissue:`17130`: autoscale_view is not working with Line3DCollection
* :ghissue:`28434`: [Bug]: Setting exactly 2 colors with tuple in ``plot`` method gives confusing error
* :ghissue:`28417`: [Doc]: axhspan and axvspan now return Rectangles, not Polygons.
* :ghissue:`28378`: [ENH]: Switch text wrapping boundary to subfigure
* :ghissue:`28404`: [Doc]: matplotlib.widgets.CheckButtons no longer has .rectangles attribute, needs removed.
* :ghissue:`28367`: [Bug]: Backend entry points can be erroneously duplicated
* :ghissue:`28358`: [Bug]: Labels don't get wrapped when set_yticks() is used in subplots
* :ghissue:`28374`: [Bug]: rcParam ``tk.window_focus: True`` is causes crash on Linux in version 3.9.0.
* :ghissue:`28324`: [Bug]: show(block=False) freezes
* :ghissue:`28239`: [Doc]: Gallery example showing 3D slice planes
* :ghissue:`27603`: [Bug]: _raw_ticker() istep
* :ghissue:`24328`: [Bug]: class Axes3D.set_box_aspect() sets wrong aspect ratios when Axes3D.view_init( vertical_axis='y') is enabled.
* :ghissue:`28221`: [Doc]: drawedges attribute described twice in matplotlib.colorbar documentation
* :ghissue:`28296`: [Doc]: Missing comma
* :ghissue:`28256`: [Bug]: axes3d.py's _on_move() converts the roll angle to radians, but then passes it to view_init() as if it were still in degrees
* :ghissue:`28267`: [Bug]: for Python 3.11.9 gor ValueError: PyCapsule_New called with null pointer
* :ghissue:`28022`: [Bug]: Type of Axes is unknown pyright
* :ghissue:`28002`: Segfault from path editor example with QtAgg
